@@ -18,11 +18,17 @@ from typing import Any, Iterable, List, Union
 
 import numpy as np
 from oqpy import Program
-from sympy import Float
 
 import braket.ir.jaqcd as ir
 from braket.circuits import circuit
-from braket.circuits.angled_gate import AngledGate, DoubleAngledGate
+from braket.circuits.angled_gate import (
+    AngledGate,
+    DoubleAngledGate,
+    _double_angled_ascii_characters,
+    _get_angles,
+    angled_ascii_characters,
+    get_angle,
+)
 from braket.circuits.free_parameter import FreeParameter
 from braket.circuits.free_parameter_expression import FreeParameterExpression
 from braket.circuits.gate import Gate
@@ -1923,7 +1929,7 @@ class GPi(AngledGate):
 
     def _to_openqasm(
         self, target: QubitSet, serialization_properties: OpenQASMSerializationProperties, **kwargs
-    ):
+    ) -> str:
         target_qubit = serialization_properties.format_target(int(target[0]))
         return f"gpi({self.angle}) {target_qubit};"
 
@@ -1942,7 +1948,7 @@ class GPi(AngledGate):
     def fixed_qubit_count() -> int:
         return 1
 
-    def bind_values(self, **kwargs):
+    def bind_values(self, **kwargs) -> GPi:
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -1953,7 +1959,7 @@ class GPi(AngledGate):
         """Registers this function into the circuit class.
 
         Args:
-            target (Qubit or int): Target qubit index.
+            target (QubitInput): Target qubit index.
             angle (Union[FreeParameterExpression, float]): Angle in radians.
 
         Returns:
@@ -1984,7 +1990,7 @@ class GPi2(AngledGate):
 
     def _to_openqasm(
         self, target: QubitSet, serialization_properties: OpenQASMSerializationProperties, **kwargs
-    ):
+    ) -> str:
         target_qubit = serialization_properties.format_target(int(target[0]))
         return f"gpi2({self.angle}) {target_qubit};"
 
@@ -2003,7 +2009,7 @@ class GPi2(AngledGate):
     def fixed_qubit_count() -> int:
         return 1
 
-    def bind_values(self, **kwargs):
+    def bind_values(self, **kwargs) -> GPi2:
         return get_angle(self, **kwargs)
 
     @staticmethod
@@ -2014,7 +2020,7 @@ class GPi2(AngledGate):
         """Registers this function into the circuit class.
 
         Args:
-            target (Qubit or int): Target qubit index.
+            target (QubitInput): Target qubit index.
             angle (Union[FreeParameterExpression, float]): Angle in radians.
 
         Returns:
@@ -2051,7 +2057,7 @@ class MS(DoubleAngledGate):
 
     def _to_openqasm(
         self, target: QubitSet, serialization_properties: OpenQASMSerializationProperties, **kwargs
-    ):
+    ) -> str:
         target_qubit_1 = serialization_properties.format_target(int(target[0]))
         target_qubit_2 = serialization_properties.format_target(int(target[1]))
         return f"ms({self.angle_1}, {self.angle_2}) {target_qubit_1}, {target_qubit_2};"
@@ -2073,7 +2079,7 @@ class MS(DoubleAngledGate):
     def fixed_qubit_count() -> int:
         return 2
 
-    def bind_values(self, **kwargs):
+    def bind_values(self, **kwargs) -> MS:
         return _get_angles(self, **kwargs)
 
     @staticmethod
@@ -2087,8 +2093,10 @@ class MS(DoubleAngledGate):
         """Registers this function into the circuit class.
 
         Args:
-            target (Qubit or int): Target qubit index.
-            angle (Union[FreeParameterExpression, float]): Angle in radians.
+            target1 (QubitInput): Target qubit 1 index.
+            target2 (QubitInput): Target qubit 2 index.
+            angle_1 (Union[FreeParameterExpression, float]): angle in radians.
+            angle_2 (Union[FreeParameterExpression, float]): angle in radians.
 
         Returns:
             Iterable[Instruction]: MS instruction.
@@ -2275,83 +2283,6 @@ class PulseGate(Gate, Parameterizable):
 Gate.register_gate(PulseGate)
 
 
-def angled_ascii_characters(gate: str, angle: Union[FreeParameterExpression, float]) -> str:
-    """
-    Generates a formatted ascii representation of an angled gate.
-
-    Args:
-        gate (str): The name of the gate.
-        angle (Union[FreeParameterExpression, float]): The angle for the gate.
-
-    Returns:
-        str: Returns the ascii representation for an angled gate.
-
-    """
-    return f'{gate}({angle:{".2f" if isinstance(angle, (float, Float)) else ""}})'
-
-
-def _double_angled_ascii_characters(
-    gate: str,
-    angle_1: Union[FreeParameterExpression, float],
-    angle_2: Union[FreeParameterExpression, float],
-) -> str:
-    """
-    Generates a formatted ascii representation of an angled gate.
-
-    Args:
-        gate (str): The name of the gate.
-        angle (Union[FreeParameterExpression, float]): The angle for the gate.
-
-    Returns:
-        str: Returns the ascii representation for an angled gate.
-
-    """
-    return (
-        f"{gate}("
-        f'{angle_1:{".2f" if isinstance(angle_1, (float, Float)) else ""}}, '
-        f'{angle_2:{".2f" if isinstance(angle_2, (float, Float)) else ""}})'
-    )
-
-
-def get_angle(self: AngledGate, **kwargs) -> AngledGate:
-    """
-    Gets the angle with all values substituted in that are requested.
-
-    Args:
-        self (AngledGate): The subclass of AngledGate for which the angle is being obtained.
-
-    Returns:
-        AngledGate: A new gate of the type of the AngledGate originally used with all
-        angles updated.
-    """
-    new_angle = (
-        self.angle.subs(kwargs) if isinstance(self.angle, FreeParameterExpression) else self.angle
-    )
-    return type(self)(angle=new_angle)
-
-
-def _get_angles(self, **kwargs):
-    """
-    Gets the angle with all values substituted in that are requested.
-
-    Args:
-        self: The subclass of AngledGate for which the angle is being obtained.
-        **kwargs: The named parameters that are being filled for a particular gate.
-
-    Returns:
-        A new gate of the type of the AngledGate originally used with all angles updated.
-    """
-    new_angles = [
-        (
-            getattr(self, angle).subs(kwargs)
-            if isinstance(getattr(self, angle), FreeParameterExpression)
-            else getattr(self, angle)
-        )
-        for angle in ("angle_1", "angle_2")
-    ]
-    return type(self)(angle_1=new_angles[0], angle_2=new_angles[1])
-
-
 def format_complex(number: complex) -> str:
     """
     Format a complex number into <a> + <b>im to be consumed by the braket unitary pragma
