@@ -16,6 +16,8 @@ from __future__ import annotations
 import functools
 import itertools
 import math
+import numbers
+from copy import deepcopy
 from typing import Dict, List, Tuple, Union
 
 import numpy as np
@@ -41,20 +43,28 @@ class H(StandardObservable):
         """
         super().__init__(ascii_symbols=["H"])
 
+    def _unscaled(self):
+        return H()
+
     def _to_jaqcd(self) -> List[str]:
+        if self.coefficient != 1:
+            raise ValueError("Observable coefficients not supported with Jaqcd")
         return ["h"]
 
     def _to_openqasm(
         self, serialization_properties: OpenQASMSerializationProperties, target: QubitSet = None
     ) -> str:
+        coef_prefix = f"{self.coefficient} * " if self.coefficient != 1 else ""
         if target:
             qubit_target = serialization_properties.format_target(int(target[0]))
-            return f"h({qubit_target})"
+            return f"{coef_prefix}h({qubit_target})"
         else:
-            return "h all"
+            return f"{coef_prefix}h all"
 
     def to_matrix(self) -> np.ndarray:
-        return 1.0 / np.sqrt(2.0) * np.array([[1.0, 1.0], [1.0, -1.0]], dtype=complex)
+        return self.coefficient * (
+            1.0 / np.sqrt(2.0) * np.array([[1.0, 1.0], [1.0, -1.0]], dtype=complex)
+        )
 
     @property
     def basis_rotation_gates(self) -> Tuple[Gate, ...]:
@@ -74,20 +84,26 @@ class I(Observable):  # noqa: E742, E261
         """
         super().__init__(qubit_count=1, ascii_symbols=["I"])
 
+    def _unscaled(self):
+        return I()
+
     def _to_jaqcd(self) -> List[str]:
+        if self.coefficient != 1:
+            raise ValueError("Observable coefficients not supported with Jaqcd")
         return ["i"]
 
     def _to_openqasm(
         self, serialization_properties: OpenQASMSerializationProperties, target: QubitSet = None
     ) -> str:
+        coef_prefix = f"{self.coefficient} * " if self.coefficient != 1 else ""
         if target:
             qubit_target = serialization_properties.format_target(int(target[0]))
-            return f"i({qubit_target})"
+            return f"{coef_prefix}i({qubit_target})"
         else:
-            return "i all"
+            return f"{coef_prefix}i all"
 
     def to_matrix(self) -> np.ndarray:
-        return np.eye(2, dtype=complex)
+        return self.coefficient * np.eye(2, dtype=complex)
 
     @property
     def basis_rotation_gates(self) -> Tuple[Gate, ...]:
@@ -99,10 +115,10 @@ class I(Observable):  # noqa: E742, E261
         Returns:
             np.ndarray: The eigenvalues of this observable.
         """
-        return np.ones(2)
+        return self.coefficient * np.ones(2)
 
     def eigenvalue(self, index: int) -> float:
-        return 1.0
+        return self.coefficient * 1.0
 
 
 Observable.register_observable(I)
@@ -118,20 +134,26 @@ class X(StandardObservable):
         """
         super().__init__(ascii_symbols=["X"])
 
+    def _unscaled(self):
+        return X()
+
     def _to_jaqcd(self) -> List[str]:
+        if self.coefficient != 1:
+            raise ValueError("Observable coefficients not supported with Jaqcd")
         return ["x"]
 
     def _to_openqasm(
         self, serialization_properties: OpenQASMSerializationProperties, target: QubitSet = None
     ) -> str:
+        coef_prefix = f"{self.coefficient} * " if self.coefficient != 1 else ""
         if target:
             qubit_target = serialization_properties.format_target(int(target[0]))
-            return f"x({qubit_target})"
+            return f"{coef_prefix}x({qubit_target})"
         else:
-            return "x all"
+            return f"{coef_prefix}x all"
 
     def to_matrix(self) -> np.ndarray:
-        return np.array([[0.0, 1.0], [1.0, 0.0]], dtype=complex)
+        return self.coefficient * np.array([[0.0, 1.0], [1.0, 0.0]], dtype=complex)
 
     @property
     def basis_rotation_gates(self) -> Tuple[Gate, ...]:
@@ -151,20 +173,26 @@ class Y(StandardObservable):
         """
         super().__init__(ascii_symbols=["Y"])
 
+    def _unscaled(self):
+        return Y()
+
     def _to_jaqcd(self) -> List[str]:
+        if self.coefficient != 1:
+            raise ValueError("Observable coefficients not supported with Jaqcd")
         return ["y"]
 
     def _to_openqasm(
         self, serialization_properties: OpenQASMSerializationProperties, target: QubitSet = None
     ) -> str:
+        coef_prefix = f"{self.coefficient} * " if self.coefficient != 1 else ""
         if target:
             qubit_target = serialization_properties.format_target(int(target[0]))
-            return f"y({qubit_target})"
+            return f"{coef_prefix}y({qubit_target})"
         else:
-            return "y all"
+            return f"{coef_prefix}y all"
 
     def to_matrix(self) -> np.ndarray:
-        return np.array([[0.0, -1.0j], [1.0j, 0.0]], dtype=complex)
+        return self.coefficient * np.array([[0.0, -1.0j], [1.0j, 0.0]], dtype=complex)
 
     @property
     def basis_rotation_gates(self) -> Tuple[Gate, ...]:
@@ -184,20 +212,26 @@ class Z(StandardObservable):
         """
         super().__init__(ascii_symbols=["Z"])
 
+    def _unscaled(self):
+        return Z()
+
     def _to_jaqcd(self) -> List[str]:
+        if self.coefficient != 1:
+            raise ValueError("Observable coefficients not supported with Jaqcd")
         return ["z"]
 
     def _to_openqasm(
         self, serialization_properties: OpenQASMSerializationProperties, target: QubitSet = None
     ) -> str:
+        coef_prefix = f"{self.coefficient} * " if self.coefficient != 1 else ""
         if target:
             qubit_target = serialization_properties.format_target(int(target[0]))
-            return f"z({qubit_target})"
+            return f"{coef_prefix}z({qubit_target})"
         else:
-            return "z all"
+            return f"{coef_prefix}z all"
 
     def to_matrix(self) -> np.ndarray:
-        return np.array([[1.0, 0.0], [0.0, -1.0]], dtype=complex)
+        return self.coefficient * np.array([[1.0, 0.0], [0.0, -1.0]], dtype=complex)
 
     @property
     def basis_rotation_gates(self) -> Tuple[Gate, ...]:
@@ -237,19 +271,45 @@ class TensorProduct(Observable):
             if isinstance(obs, TensorProduct):
                 for nested_obs in obs.factors:
                     flattened_observables.append(nested_obs)
+                # make sure you don't lose coefficient of tensor product
+                flattened_observables[-1] *= obs.coefficient
+            elif isinstance(obs, Sum):
+                raise TypeError("Sum observables not allowed in TensorProduct")
             else:
                 flattened_observables.append(obs)
-        self._factors = tuple(flattened_observables)
         qubit_count = sum([obs.qubit_count for obs in flattened_observables])
-        display_name = "@".join([obs.ascii_symbols[0] for obs in flattened_observables])
+        # aggregate all coefficients for the product, since aX @ bY == ab * X @ Y
+        coefficient = np.prod([obs.coefficient for obs in flattened_observables])
+        unscaled_factors = tuple(obs._unscaled() for obs in flattened_observables)
+        display_name = (
+            f"{coefficient if coefficient != 1 else ''}"
+            f"{'@'.join([obs.ascii_symbols[0] for obs in unscaled_factors])}"
+        )
         super().__init__(qubit_count=qubit_count, ascii_symbols=[display_name] * qubit_count)
+        self._coef = coefficient
+        self._factors = unscaled_factors
         self._factor_dimensions = tuple(
             len(factor.to_matrix()) for factor in reversed(self._factors)
         )
         self._eigenvalue_indices = {}
         self._all_eigenvalues = None
 
+    @property
+    def ascii_symbols(self) -> Tuple[str, ...]:
+        return tuple(
+            f"{self.coefficient if self.coefficient != 1 else ''}"
+            f"{'@'.join([obs.ascii_symbols[0] for obs in self.factors])}"
+            for _ in range(self.qubit_count)
+        )
+
+    def _unscaled(self):
+        copied = TensorProduct(observables=self.factors)
+        copied._coef = 1
+        return copied
+
     def _to_jaqcd(self) -> List[str]:
+        if self.coefficient != 1:
+            raise ValueError("Observable coefficients not supported with Jaqcd")
         ir = []
         for obs in self.factors:
             ir.extend(obs.to_ir())
@@ -258,6 +318,7 @@ class TensorProduct(Observable):
     def _to_openqasm(
         self, serialization_properties: OpenQASMSerializationProperties, target: QubitSet = None
     ) -> str:
+        coef_prefix = f"{self.coefficient} * " if self.coefficient != 1 else ""
         factors = []
         use_qubits = iter(target)
         for obs in self._factors:
@@ -272,7 +333,7 @@ class TensorProduct(Observable):
                     serialization_properties=serialization_properties,
                 )
             )
-        return " @ ".join(factors)
+        return f"{coef_prefix}{' @ '.join(factors)}"
 
     @property
     def factors(self) -> Tuple[Observable, ...]:
@@ -280,7 +341,9 @@ class TensorProduct(Observable):
         return self._factors
 
     def to_matrix(self) -> np.ndarray:
-        return functools.reduce(np.kron, [obs.to_matrix() for obs in self.factors])
+        return self.coefficient * functools.reduce(
+            np.kron, [obs.to_matrix() for obs in self.factors]
+        )
 
     @property
     def basis_rotation_gates(self) -> Tuple[Gate, ...]:
@@ -303,7 +366,7 @@ class TensorProduct(Observable):
             self._all_eigenvalues = TensorProduct._compute_eigenvalues(
                 self._factors, self.qubit_count
             )
-        return self._all_eigenvalues
+        return self.coefficient * self._all_eigenvalues
 
     def eigenvalue(self, index: int) -> float:
         """Returns the eigenvalue of this observable at the given index.
@@ -332,7 +395,7 @@ class TensorProduct(Observable):
             quotient, remainder = divmod(quotient, self._factor_dimensions[i])
             product *= self._factors[-i - 1].eigenvalue(remainder)
         self._eigenvalue_indices[index] = product
-        return self._eigenvalue_indices[index]
+        return self.coefficient * self._eigenvalue_indices[index]
 
     def __repr__(self):
         return "TensorProduct(" + ", ".join([repr(o) for o in self.factors]) + ")"
@@ -365,6 +428,101 @@ class TensorProduct(Observable):
 Observable.register_observable(TensorProduct)
 
 
+class Sum(Observable):
+    """Sum of observables"""
+
+    def __init__(self, observables: List[Observable], display_name: str = "Hamiltonian"):
+        """
+        Args:
+            observables (List[Observable]): List of observables for Sum
+
+        Examples:
+            >>> t1 = -3 * Observable.Y() + 2 * Observable.X()
+            Sum(X('qubit_count': 1), Y('qubit_count': 1))
+            >>> t1.summands
+            (X('qubit_count': 1), Y('qubit_count': 1))
+        """
+        flattened_observables = []
+        for obs in observables:
+            if isinstance(obs, Sum):
+                for nested_obs in obs.summands:
+                    flattened_observables.append(nested_obs)
+            else:
+                flattened_observables.append(obs)
+
+        self._summands = tuple(flattened_observables)
+        qubit_count = max(flattened_observables, key=lambda obs: obs.qubit_count).qubit_count
+        super().__init__(qubit_count=qubit_count, ascii_symbols=[display_name] * qubit_count)
+
+    def __mul__(self, other) -> Observable:
+        """Scalar multiplication"""
+        if isinstance(other, numbers.Number):
+            sum_copy = deepcopy(self)
+            for i, obs in enumerate(sum_copy.summands):
+                sum_copy._summands[i]._coef *= other
+            return sum_copy
+        raise TypeError("Observable coefficients must be numbers.")
+
+    def _to_jaqcd(self) -> List[str]:
+        raise NotImplementedError("Sum Observable is not supported in Jaqcd")
+
+    def _to_openqasm(
+        self,
+        serialization_properties: OpenQASMSerializationProperties,
+        target: List[QubitSet] = None,
+    ) -> str:
+        if len(self.summands) != len(target):
+            raise ValueError(
+                f"Invalid target of length {len(target)} for Sum with {len(self.summands)} terms"
+            )
+        for i, (term, term_target) in enumerate(zip(self.summands, target)):
+            if term.qubit_count != len(term_target):
+                raise ValueError(
+                    f"Invalid target for term {i} of Sum. "
+                    f"Expected {term.qubit_count} targets, got {len(term_target)}"
+                )
+        return " + ".join(
+            obs.to_ir(
+                target=term_target,
+                ir_type=IRType.OPENQASM,
+                serialization_properties=serialization_properties,
+            )
+            for obs, term_target in zip(self.summands, target)
+        ).replace("+ -", "- ")
+
+    @property
+    def summands(self) -> Tuple[Observable, ...]:
+        """Tuple[Observable]: The observables that comprise this sum."""
+        return self._summands
+
+    def to_matrix(self) -> np.ndarray:
+        raise NotImplementedError("Matrix operation is not supported for Sum")
+
+    @property
+    def basis_rotation_gates(self) -> Tuple[Gate, ...]:
+        raise NotImplementedError("Basis rotation calculation not supported for Sum")
+
+    @property
+    def eigenvalues(self) -> np.ndarray:
+        raise NotImplementedError("Eigenvalue calculation not supported for Sum")
+
+    def eigenvalue(self, index: int) -> float:
+        raise NotImplementedError("Eigenvalue calculation not supported for Sum")
+
+    def __repr__(self):
+        return "Sum(" + ", ".join([repr(o) for o in self.summands]) + ")"
+
+    def __eq__(self, other):
+        return repr(self) == repr(other)
+
+    @staticmethod
+    def _compute_eigenvalues(observables: Tuple[Observable], num_qubits: int) -> np.ndarray:
+        raise NotImplementedError("Eigenvalue calculation not supported for Sum")
+
+
+Observable.register_observable(Sum)
+
+
 class Hermitian(Observable):
     """Hermitian matrix as an observable."""
 
@@ -400,7 +558,12 @@ class Hermitian(Observable):
 
         super().__init__(qubit_count=qubit_count, ascii_symbols=[display_name] * qubit_count)
 
+    def _unscaled(self):
+        return Hermitian(matrix=self._matrix, display_name=self.ascii_symbols[0])
+
     def _to_jaqcd(self) -> List[List[List[List[float]]]]:
+        if self.coefficient != 1:
+            raise ValueError("Observable coefficients not supported with Jaqcd")
         return [
             [[[element.real, element.imag] for element in row] for row in self._matrix.tolist()]
         ]
@@ -408,13 +571,17 @@ class Hermitian(Observable):
     def _to_openqasm(
         self, serialization_properties: OpenQASMSerializationProperties, target: QubitSet = None
     ) -> str:
+        coef_prefix = f"{self.coefficient} * " if self.coefficient != 1 else ""
         if target:
             qubit_target = ", ".join(
                 [serialization_properties.format_target(int(t)) for t in target]
             )
-            return f"hermitian({self._serialized_matrix_openqasm_matrix()}) {qubit_target}"
+            return (
+                f"{coef_prefix}"
+                f"hermitian({self._serialized_matrix_openqasm_matrix()}) {qubit_target}"
+            )
         else:
-            return f"hermitian({self._serialized_matrix_openqasm_matrix()}) all"
+            return f"{coef_prefix}hermitian({self._serialized_matrix_openqasm_matrix()}) all"
 
     def _serialized_matrix_openqasm_matrix(self) -> str:
         serialized = str([[f"{complex(elem)}" for elem in row] for row in self._matrix.tolist()])
@@ -423,7 +590,7 @@ class Hermitian(Observable):
         return serialized
 
     def to_matrix(self) -> np.ndarray:
-        return self._matrix
+        return self.coefficient * self._matrix
 
     def __eq__(self, other) -> bool:
         return self.matrix_equivalence(other)
